<?php
/**
 * @package WordPress
 * @subpackage Constructor
 */

add_action('admin_menu', 'constructor_theme_page_add');

wp_enqueue_script('jquery');
wp_enqueue_script('jquery-ui-tabs');
wp_enqueue_script('thickbox');
wp_enqueue_script('constructor-colorpicker', get_template_directory_uri().'/admin/js/colorpicker.js', 'jquery');
wp_enqueue_script('constructor-settings',    get_template_directory_uri().'/admin/js/settings.js', 'jquery');

wp_enqueue_style('thickbox');
wp_enqueue_style('constructor-admin',       get_template_directory_uri().'/admin/css/admin.css');
wp_enqueue_style('constructor-colorpicker', get_template_directory_uri().'/admin/css/colorpicker.css');
wp_enqueue_style('jquery.ui.tabs',          get_template_directory_uri().'/admin/css/jquery.ui.tabs.css');

/**
 * Add configuration page
 */
function constructor_theme_page_add()
{
    session_start();

    if ( isset( $_REQUEST['action'] ) && 'save' == $_REQUEST['action'] ) {
        check_admin_referer('constructor');
        if (isset($_REQUEST['constructor'])) {

            $files = $_FILES['constructor'];
            $data  = $_REQUEST['constructor'];
            $directory = get_template_directory();
            
            if (isset ($data['theme-reload']) && $data['theme-reload'] != 0) {
                $theme = $data['theme'];
                $data  = require $directory.'/themes/'.$theme.'/config.php';
            } else {
                $upload = $directory.'/images/';

                if ($files && is_writable($directory.'/images/'))

                $errors = array();
                foreach ($files['name']['images'] as $name => $image) {
                    if (isset($image['src']) && is_uploaded_file($files['tmp_name']['images'][$name]['src'])) {

                        if (!preg_match('/\.(jpe?g|png|gif)$/i', $image['src'])) {
                            $errors[] = sprintf(__('File "%s" is not a image','constructor'), $image['src']);
                            continue;
                        }

                        if (move_uploaded_file($files['tmp_name']['images'][$name]['src'], $upload . $image['src'])) {
                            $data['images'][$name]['src'] = 'images/'.$image['src'];
                        }
                    }
                }
                $_SESSION['constructor-errors'] = $errors;

                /**
                 * CSS changes
                 */
                if (isset($data['css']) && is_writable($directory.'/themes/'.$data['theme'].'/styles.css')) {
                    file_put_contents($directory.'/themes/'.$data['theme'].'/styles.css', $data['css']);
                    unset($data['css']);
                }

                /**
                 * Slideshow
                 */
                $data['slideshow']['id'] = (int)$data['slideshow']['id'];

                if (isset($data['slideshow']['onpage']))   $data['slideshow']['onpage'] = true;
                if (isset($data['slideshow']['onsingle'])) $data['slideshow']['onsingle'] = true;

                /**
                 * Merge Configuration
                 */
                $constructor = get_option('constructor') or $constructor = array();
                $data = array_merge($constructor, $data);
            }
            
            // show text message
            update_option('constructor', $data);
        }
        wp_redirect("themes.php?page=functions.php&saved=true");
        die;
    }
    add_theme_page(__('Customize Theme', 'constructor'), __('Customize', 'constructor'), 'edit_themes', 'functions.php', 'constructor_theme_page');
}


/**
 * Configuration page
 *
 */
function constructor_theme_page()
{
    $constructor   = get_option('constructor');
    $directory     = get_template_directory();
    $directory_uri = get_template_directory_uri();

    if (!$constructor) {
        $constructor = require $directory.'/themes/default/config.php';
    }

    $fonts = require 'fonts.php';

    $themes = scandir($directory.'/themes/');
    unset($themes[array_search('.', $themes)]);
    unset($themes[array_search('..', $themes)]);

    ?>

    <div class='wrap'>
       <h2><?php _e('Customize Theme', 'constructor'); ?></h2>
       <?php if ( isset( $_REQUEST['saved'] ) ) echo '<div id="message" class="updated fade"><p><strong>'.__('Options saved.').'</strong></p></div>'; ?>
       <?php
       if ( isset( $_SESSION['constructor-errors']) && !empty ($_SESSION['constructor-errors'])) {
           echo '<div id="errors" class="error fade">';
           echo '<p><strong>'.__('Errors', 'constructor').'</strong></p>';
           foreach ($_SESSION['constructor-errors'] as $error) {
               echo "<p>{$error}</p>";
           }
           echo '</div>';
           unset ($_SESSION['constructor-errors']);
       }
       ?>
       <div class="constructor">
            <form method="post" id="constructor-form" action="<?php echo attribute_escape($_SERVER['REQUEST_URI']); ?>" enctype="multipart/form-data">
                <?php wp_nonce_field('constructor'); ?>
                <input type="hidden" id="constructor-sidebar" name="constructor[sidebar]" value="<?php echo $constructor['sidebar']?>"/>
                <input type="hidden" id="constructor-theme" name="constructor[theme]" value="<?php echo $constructor['theme']?>"/>
                <input type="hidden" id="constructor-theme-reload" name="constructor[theme-reload]" value="0"/>

                <input type="hidden" id="constructor-slideshow" name="constructor[slideshow][id]" value="<?php echo $constructor['slideshow']['id']?>"/>


                <input type="hidden" id="constructor-opacity" name="constructor[opacity]" value="<?php echo $constructor['opacity']?>"/>

                <input type="hidden" id="constructor-title-pos" name="constructor[title][pos]" value="<?php echo $constructor['title']['pos']?>"/>

                <input type="hidden" id="constructor-color_title" name="constructor[color][title]" value="<?php echo $constructor['color']['title']?>"/>
                <input type="hidden" id="constructor-color_title2" name="constructor[color][title2]" value="<?php echo $constructor['color']['title2']?>"/>

                <input type="hidden" id="constructor-color_bg" name="constructor[color][bg]" value="<?php echo $constructor['color']['bg']?>"/>
                <input type="hidden" id="constructor-color_bg2" name="constructor[color][bg2]" value="<?php echo $constructor['color']['bg2']?>"/>

                <input type="hidden" id="constructor-color_text" name="constructor[color][text]" value="<?php echo $constructor['color']['text']?>"/>
                <input type="hidden" id="constructor-color_text2" name="constructor[color][text2]" value="<?php echo $constructor['color']['text2']?>"/>

                <input type="hidden" id="constructor-color_border" name="constructor[color][border]" value="<?php echo $constructor['color']['border']?>"/>
                <input type="hidden" id="constructor-color_border2" name="constructor[color][border2]" value="<?php echo $constructor['color']['border2']?>"/>

                <input type="hidden" id="constructor-color_header1" name="constructor[color][header1]" value="<?php echo $constructor['color']['header1']?>"/>
                <input type="hidden" id="constructor-color_header2" name="constructor[color][header2]" value="<?php echo $constructor['color']['header2']?>"/>
                <input type="hidden" id="constructor-color_header3" name="constructor[color][header3]" value="<?php echo $constructor['color']['header3']?>"/>
                <input type="hidden" id="constructor-color_alt" name="constructor[color][alt]" value="<?php echo $constructor['color']['alt']?>"/>

                <input type="hidden" id="constructor-images-wrap-pos" name="constructor[images][wrap][pos]" value="<?php echo $constructor['images']['wrap']['pos']?>"/>
                <input type="hidden" id="constructor-images-sidebar-pos" name="constructor[images][sidebar][pos]" value="<?php echo $constructor['images']['sidebar']['pos']?>"/>
                <input type="hidden" id="constructor-images-footer-pos" name="constructor[images][footer][pos]" value="<?php echo $constructor['images']['footer']['pos']?>"/>

                <input type="hidden" name="action" value="save" />


                <ul id="tabs">
                    <li><a href="#themes"><?php _e('Themes', 'constructor'); ?></a></li>
                    <li><a href="#layout"><?php _e('Layout', 'constructor'); ?></a></li>
                    <li><a href="#header"><?php _e('Header', 'constructor'); ?></a></li>
                    <li><a href="#colors"><?php _e('Colors', 'constructor'); ?></a></li>
                    <li><a href="#fonts"><?php _e('Fonts', 'constructor'); ?></a></li>
                    <li><a href="#css"><?php _e('CSS', 'constructor'); ?></a></li>
                    <li><a href="#images"><?php _e('Images', 'constructor'); ?></a></li>
                    <li><a href="#gallery"><?php _e('Slideshow', 'constructor'); ?></a></li>
                </ul>

                <div id="themes">
                    <?php foreach ($themes as $theme) :
                              $img = null;
                              if (file_exists($directory.'/themes/'.$theme.'/styles.css')) {
                                  $data = get_theme_data($directory.'/themes/'.$theme.'/styles.css');

                                  if (file_exists($directory.'/themes/'.$theme.'/screenshot.png')) {
                                      $img = $directory_uri .'/themes/'.$theme.'/screenshot.png';
                                  }
                              } else {
                                  $data = array(
                                      'Title' => $theme,
                                      'Description' => __('File "styles.css" is not exists','constructor'),
                                      'Author' => __('Anonymous','constructor'),
                                      'Version' => '0.0',
                                  );

                              }
                    ?>

                         <div <?php if($constructor['theme'] == $theme) echo 'class="selected"'; ?> title="<?php echo $theme ?>">
                            <span>
                                <?php if ($img): ?>
                                <img src="<?php echo $img ;?>" />
                                <?php endif; ?>
                            </span>
                            <strong><?php echo $data['Title'] ?></strong> <em>@<?php echo $data['Author'] ?></em>- <?php _e('version', 'constructor'); ?> <?php echo $data['Version'] ?>
                            <p><?php echo $data['Description'] ?></p>
                         </div>
                    <?php endforeach; ?>
                    <br class="clear"/>
                </div>
                
                <div id="layout">
                    <table class="form-table">
                    <tr>
                        <th scope="row" valign="top"><?php _e('Sidebar', 'constructor'); ?></th>
                        <td class="select" id="sidebar">
                            <a href="#" title="<?php echo attribute_escape(__('Left', 'constructor')); ?>" name="left" <?php if($constructor['sidebar'] == 'left') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-left.png" alt="<?php echo attribute_escape(__('Left', 'constructor')); ?>" />
                            </a>
                            <a href="#" title="<?php echo attribute_escape(__('Right', 'constructor')); ?>" name="right" <?php if($constructor['sidebar'] == 'right') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-right.png" alt="<?php echo attribute_escape(__('Right', 'constructor')); ?>" />
                            </a>
                            <br class="clear"/>
                            <a href="#" title="<?php echo attribute_escape(__('Two', 'constructor')); ?>" name="two" <?php if($constructor['sidebar'] == 'two') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-two.png" alt="<?php echo attribute_escape(__('Two', 'constructor')); ?>" />
                            </a>
                            <a href="#" title="<?php echo attribute_escape(__('None', 'constructor')); ?>" name="none" <?php if($constructor['sidebar'] == 'none') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-none.png" alt="<?php echo attribute_escape(__('None', 'constructor')); ?>" />
                            </a>
                            <br class="clear"/>
                            <a href="#" title="<?php echo attribute_escape(__('Two Right', 'constructor')); ?>" name="two-right" <?php if($constructor['sidebar'] == 'two-right') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-two-right.png" alt="<?php echo attribute_escape(__('Two Right', 'constructor')); ?>" />
                            </a>
                            <a href="#" title="<?php echo attribute_escape(__('Two Left', 'constructor')); ?>" name="two-left" <?php if($constructor['sidebar'] == 'two-left') echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/sidebar-two-left.png" alt="<?php echo attribute_escape(__('Two Left', 'constructor')); ?>" />
                            </a>
                        </td>
                    </tr>
                    </table>
                </div>

                <div id="header">
                    <table class="form-table">
                    <tr>
                        <th scope="row" valign="top"><?php _e('Title position', 'constructor'); ?></th>
                        <td class="position select" id="title-pos">
                            <a href="#" title="<?php _e('Left', 'constructor'); ?>" name="left" <?php if($constructor['title']['pos'] == 'left') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center', 'constructor'); ?>" name="center" <?php if($constructor['title']['pos'] == 'center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Right', 'constructor'); ?>" name="right" <?php if($constructor['title']['pos'] == 'right') echo 'class="selected"'; ?>> </a>
                            <br class="clear"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Title colors', 'constructor'); ?></th>
                        <td class="color-selector">
                            <div id="color_title" class="color"><div style="background-color: <?php echo $constructor['color']['title'] ?>"></div></div>
                            - <?php echo attribute_escape(__('title', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_title2" class="color"><div style="background-color: <?php echo $constructor['color']['title2'] ?>"></div></div>
                            - <?php echo attribute_escape(__('description', 'constructor')); ?>
                            <br class="clear"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Header menu', 'constructor'); ?></th>
                        <td>
                            <input type="radio" id="constructor-links-1" name="constructor[links][type]" value="1" <?php if ($constructor['links']['type'] == 1) echo 'checked="checked"'; ?> />
                            <label for="constructor-links-1"><?php _e('Don\'t show menu', 'constructor'); ?></label>
                            <br/>
                            <input type="radio" id="constructor-links-2" name="constructor[links][type]" value="2" <?php if ($constructor['links']['type'] == 2) echo 'checked="checked"'; ?> />
                            <label for="constructor-links-2"><?php _e('Show first-level pages', 'constructor'); ?></label>
                            <br/>
                            <input type="radio" id="constructor-links-3" name="constructor[links][type]" value="3" <?php if ($constructor['links']['type'] == 3) echo 'checked="checked"'; ?> />
                            <label for="constructor-links-3"><?php _e('Show pages in drop-down menu', 'constructor'); ?></label>
                            <br/>
                            <input type="radio" id="constructor-links-4" name="constructor[links][type]" value="4" <?php if ($constructor['links']['type'] == 4) echo 'checked="checked"'; ?> />
                            <label for="constructor-links-4"><?php _e('Show pages in drop-down menu (2-levels)', 'constructor'); ?></label>
                            <br/>
                            <input type="checkbox" id="constructor-links-home" name="constructor[links][home]" value="1" <?php if ($constructor['links']['home']) echo 'checked="checked"'; ?>/>
                            <label for="constructor-links-home"><?php _e('Show link to home page', 'constructor'); ?></label>
                            <br/>
                            <input type="checkbox" id="constructor-links-rss" name="constructor[links][rss]" value="1" <?php if ($constructor['links']['rss']) echo 'checked="checked"'; ?>/>
                            <label for="constructor-links-rss"><?php _e('Show link to RSS feed', 'constructor'); ?></label>
                            <br/>
                            <input type="checkbox" id="constructor-links-size" name="constructor[links][size]" value="1" <?php if ($constructor['links']['size']) echo 'checked="checked"'; ?>/>
                            <label for="constructor-links-size"><?php _e('Show font resizer', 'constructor'); ?></label>
                        </td>
                    </tr>
                    </table>
                </div>
                <div id="colors">
                    <table class="form-table">
                    <tr>
                        <th scope="row" valign="top"><?php _e('Opacity', 'constructor'); ?></th>
                        <td class="select" id="opacity" >
                            <a href="#" title="<?php echo attribute_escape(__('Dark', 'constructor')); ?>" name="dark" <?php if($constructor['opacity'] == 'dark') echo 'class="selected"'; ?>>
                                <div class="dark"><?php echo attribute_escape(__('Dark', 'constructor')); ?></div>
                            </a>
                            <a href="#" title="<?php echo attribute_escape(__('Light', 'constructor')); ?>" name="light" <?php if($constructor['opacity'] == 'light') echo 'class="selected"'; ?>>
                                <div class="light"><?php echo attribute_escape(__('Light', 'constructor')); ?></div>
                            </a>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Elements Colors', 'constructor'); ?></th>
                        <td class="color-selector">
                            <div id="color_bg" class="color"><div style="background-color: <?php echo $constructor['color']['bg'] ?>"></div></div>
                            - <?php echo attribute_escape(__('background', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_bg2" class="color"><div style="background-color: <?php echo $constructor['color']['bg2'] ?>"></div></div>
                            - <?php echo attribute_escape(__('background alternative', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_text" class="color"><div style="background-color: <?php echo $constructor['color']['text'] ?>"></div></div>
                            - <?php echo attribute_escape(__('text', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_text2" class="color"><div style="background-color: <?php echo $constructor['color']['text2'] ?>"></div></div>
                            - <?php echo attribute_escape(__('text alternative', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_border" class="color"><div style="background-color: <?php echo $constructor['color']['border'] ?>"></div></div>
                            - <?php echo attribute_escape(__('border', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_border2" class="color"><div style="background-color: <?php echo $constructor['color']['border2'] ?>"></div></div>
                            - <?php echo attribute_escape(__('border alternative', 'constructor')); ?>
                            <br class="clear"/>
                            <div id="color_header1" class="color"><div style="background-color: <?php echo $constructor['color']['header1'] ?>"></div></div>
                            - <?php echo attribute_escape(__('tags', 'constructor')); ?> H1, H2, HR, A:hover
                            <br class="clear"/>
                            <div id="color_header2" class="color"><div style="background-color: <?php echo $constructor['color']['header2'] ?>"></div></div>
                            - <?php echo attribute_escape(__('tags', 'constructor')); ?> H3, H4
                            <br class="clear"/>
                            <div id="color_header3" class="color"><div style="background-color: <?php echo $constructor['color']['header3'] ?>"></div></div>
                            - <?php echo attribute_escape(__('tags', 'constructor')); ?> H5, H6, TH
                            <br class="clear"/>
                        </td>
                    </tr>
                    </table>
                </div>
                <div id="fonts">
                    <table class="form-table">
                        <tr>
                            <th scope="row" valign="top"><?php _e('Header Font', 'constructor'); ?></th>
                            <td valign="middle">
                                <?php foreach ($fonts as $key => $font) : ?>
                                    <input type="radio" id="constructor-fonts-header-<?php echo $key ?>" name="constructor[fonts][header]" value="<?php echo $key ?>" <?php if ($constructor['fonts']['header'] == $key) echo 'checked="checked"'; ?> />
                                    <label for="constructor-fonts-header-<?php echo $key ?>" style='font-family:<?php echo $font ?>;'><?php _e('The quick brown fox jumps over the lazy dog', 'constructor'); ?></label>
                                    <br/>
                                <?php endforeach; ?>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row" valign="top"><?php _e('Body Font', 'constructor'); ?></th>
                            <td>
                                <?php foreach ($fonts as $key => $font) : ?>
                                    <input type="radio" id="constructor-fonts-body-<?php echo $key ?>" name="constructor[fonts][body]" value="<?php echo $key ?>" <?php if ($constructor['fonts']['body'] == $key) echo 'checked="checked"'; ?> />
                                    <label for="constructor-fonts-body-<?php echo $key ?>" style='font-family:<?php echo $font ?>;'><?php _e('The quick brown fox jumps over the lazy dog', 'constructor'); ?></label>
                                    <br/>
                                <?php endforeach; ?>
                            </td>
                        </tr>

                    </table>
                </div>
                <div id="css">
                    <table class="form-table">
                    <?php if (!is_writable($directory .'/themes/'.$constructor['theme'].'/styles.css')) : ?>
                        <tr>
                            <th scope="row" valign="top" colspan="2" class="th-full updated"><?php printf(__('<font color="red"><b>Warning!</b></font>: File "%s" is not writable.', 'constructor'), $directory .'/themes/'.$constructor['theme'].'/styles.css'); ?></th>
                        </tr>
                        <tr>
                            <td class="td-full"><textarea name="null[css]" readonly="readonly"><?php echo file_get_contents($directory .'/themes/'.$constructor['theme'].'/styles.css')?></textarea></td>
                        </tr>
                    <?php else: ?>
                        <tr>
                            <td class="td-full"><textarea name="constructor[css]"><?php echo file_get_contents($directory .'/themes/'.$constructor['theme'].'/styles.css')?></textarea></td>
                        </tr>
                    <?php endif; ?>
                    </table>
                </div>

                <div id="images">
                <table class="form-table">
                    <?php if (!is_writable($directory.'/images/')) : ?>
                    <tr>
                        <th scope="row" valign="top" colspan="2" class="th-full updated"><?php printf(__('<font color="red"><b>Warning!</b></font>: Directory "%s" is not writable.', 'constructor'), $directory.'/images/'); ?></th>
                    </tr>
                    <?php endif; ?>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Background Gradient', 'constructor'); ?></th>
                        <td>
                            <input type="text" name="constructor[images][body][src]" value="<?php echo $constructor['images']['body']['src']?>"/>
                            <?php if($constructor['images']['body']['src']) : ?>
                            (<a class="thickbox" href="<?php echo $directory_uri .'/'.$constructor['images']['body']['src']; ?>"><?php _e('preview', 'constructor'); ?></a>)
                            <?php endif; ?>
                            <input type="file" name="constructor[images][body][src]"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Background Image', 'constructor'); ?></th>
                        <td>
                            <input type="text" name="constructor[images][wrap][src]" value="<?php echo $constructor['images']['wrap']['src']?>"/>
                            <?php if($constructor['images']['wrap']['src']) : ?>
                            (<a class="thickbox" href="<?php echo $directory_uri .'/'.$constructor['images']['wrap']['src']; ?>"><?php _e('preview', 'constructor'); ?></a>)
                            <?php endif; ?>
                            <input type="file" name="constructor[images][wrap][src]"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Image Position', 'constructor'); ?></th>
                        <td class="position select" id="images-wrap-pos">
                            <a href="#" title="<?php _e('Top Left', 'constructor'); ?>" name="left top" <?php if($constructor['images']['wrap']['pos'] == 'left top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Center', 'constructor'); ?>" name="center top" <?php if($constructor['images']['wrap']['pos'] == 'center top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Right', 'constructor'); ?>" name="right top" <?php if($constructor['images']['wrap']['pos'] == 'right top') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Center Left', 'constructor'); ?>" name="left center" <?php if($constructor['images']['wrap']['pos'] == 'left center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Center', 'constructor'); ?>" name="center center" <?php if($constructor['images']['wrap']['pos'] == 'center center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Right', 'constructor'); ?>" name="right center" <?php if($constructor['images']['wrap']['pos'] == 'right center') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Bottom Left', 'constructor'); ?>" name="left bottom" <?php if($constructor['images']['wrap']['pos'] == 'left bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Center', 'constructor'); ?>" name="center bottom" <?php if($constructor['images']['wrap']['pos'] == 'center bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Right', 'constructor'); ?>" name="right bottom" <?php if($constructor['images']['wrap']['pos'] == 'right bottom') echo 'class="selected"'; ?>> </a>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Sidebar Image', 'constructor'); ?></th>
                        <td>
                            <input type="text" name="constructor[images][sidebar][src]" value="<?php echo $constructor['images']['sidebar']['src']?>"/>
                            <?php if($constructor['images']['sidebar']['src']) : ?>
                            (<a class="thickbox" href="<?php echo $directory_uri .'/'.$constructor['images']['sidebar']['src']; ?>"><?php _e('preview', 'constructor'); ?></a>)
                            <?php endif; ?>
                            <input type="file" name="constructor[images][sidebar][src]"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Image Position', 'constructor'); ?></th>
                        <td class="position select" id="images-sidebar-pos">
                            <a href="#" title="<?php _e('Top Left', 'constructor'); ?>" name="left top" <?php if($constructor['images']['sidebar']['pos'] == 'left top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Center', 'constructor'); ?>" name="center top" <?php if($constructor['images']['sidebar']['pos'] == 'center top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Right', 'constructor'); ?>" name="right top" <?php if($constructor['images']['sidebar']['pos'] == 'right top') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Center Left', 'constructor'); ?>" name="left center" <?php if($constructor['images']['sidebar']['pos'] == 'left center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Center', 'constructor'); ?>" name="center center" <?php if($constructor['images']['sidebar']['pos'] == 'center center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Right', 'constructor'); ?>" name="right center" <?php if($constructor['images']['sidebar']['pos'] == 'right center') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Bottom Left', 'constructor'); ?>" name="left bottom" <?php if($constructor['images']['sidebar']['pos'] == 'left bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Center', 'constructor'); ?>" name="center bottom" <?php if($constructor['images']['sidebar']['pos'] == 'center bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Right', 'constructor'); ?>" name="right bottom" <?php if($constructor['images']['sidebar']['pos'] == 'right bottom') echo 'class="selected"'; ?>> </a>

                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Footer Image', 'constructor'); ?></th>
                        <td>
                            <input type="text" name="constructor[images][footer][src]" value="<?php echo $constructor['images']['footer']['src']?>"/>
                            <?php if($constructor['images']['footer']['src']) : ?>
                            (<a class="thickbox" href="<?php echo $directory_uri .'/'.$constructor['images']['footer']['src']; ?>"><?php _e('preview', 'constructor'); ?></a>)
                            <?php endif; ?>
                            <input type="file" name="constructor[images][footer][src]"/>
                        </td>
                    </tr>
                    <tr>
                        <th scope="row" valign="top"><?php _e('Image Position', 'constructor'); ?></th>
                        <td class="position select" id="images-footer-pos">
                            <a href="#" title="<?php _e('Top Left', 'constructor'); ?>" name="left top" <?php if($constructor['images']['footer']['pos'] == 'left top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Center', 'constructor'); ?>" name="center top" <?php if($constructor['images']['footer']['pos'] == 'center top') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Top Right', 'constructor'); ?>" name="right top" <?php if($constructor['images']['footer']['pos'] == 'right top') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Center Left', 'constructor'); ?>" name="left center" <?php if($constructor['images']['footer']['pos'] == 'left center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Center', 'constructor'); ?>" name="center center" <?php if($constructor['images']['footer']['pos'] == 'center center') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Center Right', 'constructor'); ?>" name="right center" <?php if($constructor['images']['footer']['pos'] == 'right center') echo 'class="selected"'; ?>> </a>

                            <br class="clear"/>

                            <a href="#" title="<?php _e('Bottom Left', 'constructor'); ?>" name="left bottom" <?php if($constructor['images']['footer']['pos'] == 'left bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Center', 'constructor'); ?>" name="center bottom" <?php if($constructor['images']['footer']['pos'] == 'center bottom') echo 'class="selected"'; ?>> </a>
                            <a href="#" title="<?php _e('Bottom Right', 'constructor'); ?>" name="right bottom" <?php if($constructor['images']['footer']['pos'] == 'right bottom') echo 'class="selected"'; ?>> </a>
                         </td>
                    </tr>
                    </table>
                </div>
                <div id="gallery">
                    <table class="form-table">
                    <?php
                    global $nggdb;
                    if ($nggdb) :
                        $gallerylist = $nggdb->find_all_galleries();
                    ?>
                    <tr>
                        <th scope="row" valign="top" rowspan="3"><?php _e('Slideshow', 'constructor'); ?> (<em><small><?php _e('use <a href="http://wordpress.org/extend/plugins/nextgen-gallery/">NextGEN-Gallery</a>', 'constructor');?></small></em>)</th>
                        <td>
                            <label for="constructor-slideshow-height"><?php _e('Slideshow height', 'constructor'); ?> <em>(<?php _e('in px', 'constructor'); ?>)</em></label>
                            <input type="text" id="constructor-slideshow-height" name="constructor[slideshow][height]" value="<?php echo $constructor['slideshow']['height']?>"/>
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <input type="checkbox" id="constructor-slideshow-onpage" name="constructor[slideshow][onpage]" value="1" <?php if ($constructor['slideshow']['onpage']) echo 'checked="checked"'; ?> />
                            <label for="constructor-slideshow-onpage"><?php _e('Show on page', 'constructor')?></label>
                            <br/>
                            <input type="checkbox" id="constructor-slideshow-onsingle" name="constructor[slideshow][onsingle]" value="1" <?php if ($constructor['slideshow']['onsingle']) echo 'checked="checked"'; ?> />
                            <label for="constructor-slideshow-onsingle"><?php _e('Show on single post', 'constructor')?></label>
                        </td>
                    </tr>
                    <tr>
                        <td class="select" id="slideshow">
                            <a href="#" title="<?php _e('Disable', 'constructor'); ?>" name="0" <?php if($constructor['slideshow']['id'] == 0) echo 'class="selected"'; ?>>
                                <img src="<?php echo $directory_uri ?>/admin/images/disable.png" title="<?php _e('Disable', 'constructor'); ?>" alt="<?php _e('Disable', 'constructor'); ?>"/>
                            </a>
                            <?php foreach ($gallerylist as $gallery) :?>
                                <?php $img = nggdb::find_image($gallery->previewpic); ?>
                                <a href="#" title="<?php echo $gallery->title ?>" name="<?php echo $gallery->gid ?>" <?php if($constructor['slideshow']['id'] == $gallery->gid) echo 'class="selected"'; ?>>
                                <img src="<?php echo $img->thumbURL ?>" title="<?php echo $gallery->title ?>" alt="<?php echo $gallery->title ?>"/>
                                </a>
                            <?php endforeach;?>
                        </td>
                    </tr>
                    <?php
                    else :
                    ?>
                    <tr>
                        <th scope="row" valign="top" colspan="2" class="th-full"><?php _e('If you want to display slideshow on homepage, please install <a href="http://wordpress.org/extend/plugins/nextgen-gallery/">NextGEN-Gallery</a> plugin', 'constructor'); ?></th>
                    </tr>
                    <?php
                    endif;
                    ?>
                    </table>
                </div>
                <p class="submit">
                    <input type="submit" name="Submit" class="button-primary" value="<?php _e('Save Changes', 'constructor')?>" />
                </p>
            </form>
       </div>
    </div>
    <?
}
?>